@@ -1,3 +1,4 @@
+import inspect
 import os.path
 
 from binascii import unhexlify
@@ -8,6 +9,8 @@ log = False
 
 def parse_me(definition, hexstring, expected):
 	fic = FormatInfoContainer(load_from_string=definition)
+	definition_roundtrip = fic.to_text().replace("\t", " " * 8)
+	assert definition_roundtrip == inspect.cleandoc(definition)
 	pc = ParseContext(fic, unhexlify(hexstring.replace(" ","")), logging_enabled=log)
 	result = pc.parse()
 	if pc.failed:
